Learn R Programming

sparr (version 0.3-4)

as.im.bivden: Converting a sparr bivariate kernel density estimate or relative risk surface object into a spatstat pixel image.

Description

as.im methods for classes "bivden" and "rrs"

Usage

## S3 method for class 'bivden':
as.im(X, \dots)
## S3 method for class 'rrs':
as.im(X, \dots)

Arguments

X
An object of class "bivden" resulting from a call to bivariate.density, or an object of class "rss" resulting from a call to risk
...
Ignored.

Value

  • An object of class im corresponding to the supplied argument. Additional return information originally part of X is lost.

See Also

im, as.im

Examples

Run this code
data(chorley)

ch.bivden <- bivariate.density(chorley, ID = "lung", adaptive = FALSE, pilotH = 1.5)
ch.im <- as.im(ch.bivden)
summary(ch.im)

Run the code above in your browser using DataLab