powered by
sparr
spatstat
as.im methods for classes "bivden" and "rrs"
as.im
"bivden"
"rrs"
# S3 method for bivden as.im(X, …) # S3 method for rrs as.im(X, …)
An object of class "bivden" resulting from a call to bivariate.density, or an object of class "rss" resulting from a call to risk.
bivariate.density
"rss"
risk
Ignored.
An object of class im corresponding to the supplied argument. Additional return information originally part of X is lost.
im
X
im, as.im
# NOT RUN { data(chorley) ch.bivden <- bivariate.density(chorley, ID = "lung", adaptive = FALSE, pilotH = 1.5) ch.im <- as.im(ch.bivden) summary(ch.im) # }
Run the code above in your browser using DataLab